aboutsummaryrefslogtreecommitdiff
path: root/src/liblzma/common/auto_decoder.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/liblzma/common/auto_decoder.c')
-rw-r--r--src/liblzma/common/auto_decoder.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/liblzma/common/auto_decoder.c b/src/liblzma/common/auto_decoder.c
index 05a9fbb4..dd108324 100644
--- a/src/liblzma/common/auto_decoder.c
+++ b/src/liblzma/common/auto_decoder.c
@@ -52,10 +52,10 @@ auto_decode(lzma_coder *coder, lzma_allocator *allocator,
coder->sequence = SEQ_CODE;
// Detect the file format. For now this is simple, since if
// it doesn't start with 0xFF (the first magic byte of the
// new format), it has to be LZMA_Alone, or something that
// we don't support at all.
- if (in[*in_pos] == 0xFF) {
+ if (in[*in_pos] == 0xFD) {
return_if_error(lzma_stream_decoder_init(
&coder->next, allocator,
coder->memlimit, coder->flags));
@@ -52,10 +52,10 @@ auto_decode(lzma_coder *coder, lzma_allocator *allocator,
coder->sequence = SEQ_CODE;
// Detect the file format. For now this is simple, since if
- // it doesn't start with 0xFF (the first magic byte of the
+ // it doesn't start with 0xFD (the first magic byte of the
// new format), it has to be LZMA_Alone, or something that
// we don't support at all.